## Credits

### Development Lead

* Trevor James Smith <smith.trevorj@ouranos.ca> [@Zeitsperre](https://github.com/Zeitsperre)

### Co-Developers

* David Huard <huard.david@ouranos.ca> [@huard](https://github.com/huard)
